@@ -1,2 +1,2 @@
-int x;
+int x = 10;
 extern int aliasx __attribute__((__alias__("x")));
