@@ -7,12 +7,12 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 
 #undef isblank_l
 int
-isblank_l (int c, struct __locale_t *locale)
+isblank_l (int c, locale_t locale)
 {
 #if _PICOLIBC_CTYPE_SMALL
     (void) locale;
     return isblank(c);
 #else
-    return (__locale_ctype_ptr_l (locale)[c+1] & _B) || (c == '\t');
+    return (__CTYPE_PTR_L (locale)[c+1] & _B) || (c == '\t');
 #endif
 }
