@@ -7,13 +7,13 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 
 #undef isupper_l
 int
-isupper_l (int c, struct __locale_t *locale)
+isupper_l (int c, locale_t locale)
 {
 #if _PICOLIBC_CTYPE_SMALL
     (void) locale;
     return isupper(c);
 #else
-    return (__locale_ctype_ptr_l (locale)[c+1] & (_U|_L)) == _U;
+    return (__CTYPE_PTR_L (locale)[c+1] & (_U|_L)) == _U;
 #endif
 }
 
