@@ -7,18 +7,14 @@ Modified (m) 2017 Thomas Wolff: revise Unicode and locale/wchar handling
 #include <ctype.h>
 #include <wctype.h>
 #include "local.h"
-#include "categories.h"
 
 int
-iswblank_l (wint_t c, struct __locale_t *locale)
+iswblank_l (wint_t c, locale_t locale)
 {
   (void) locale;
 #ifdef _MB_CAPABLE
-  c = _jp2uc_l (c, locale);
-  enum category cat = category (c);
-  // exclude "<noBreak>"?
-  return cat == CAT_Zs
-      || c == '\t';
+  uint16_t cat = __ctype_table_lookup(c, locale);
+  return cat & CLASS_blank;
 #else
   return c < 0x100 ? isblank (c) : 0;
 #endif /* _MB_CAPABLE */
