@@ -12,20 +12,16 @@
 #ifndef _FENV_H
 #define _FENV_H
 
-#include <sys/fenv.h>
+#include <sys/cdefs.h>
 
-#ifndef FE_TONEAREST
-#define FE_TONEAREST	0
-#endif
+_BEGIN_STD_C
+
+#include <machine/fenv.h>
 
 #ifndef FE_ALL_EXCEPT
 #define FE_ALL_EXCEPT	0
 #endif
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /* Exception */
 int feclearexcept(int excepts);
 int fegetexceptflag(fexcept_t *flagp, int excepts);
@@ -43,9 +39,11 @@ int feholdexcept(fenv_t *envp);
 int fesetenv(const fenv_t *envp);
 int feupdateenv(const fenv_t *envp);
 
+#if __GNU_VISIBLE
 int feenableexcept(int);
 int fedisableexcept(int);
 int fegetexcept(void);
+#endif
 
 /*
  * Lastly, a FE_DFL_ENV macro must be defined, representing a pointer
@@ -73,8 +71,6 @@ int fesetexcept(int excepts);
 
 #endif
 
-#ifdef __cplusplus
-}
-#endif
+_END_STD_C
 
 #endif
