@@ -53,31 +53,8 @@ __bswap64(__uint64_t _x)
 }
 #endif /* !__GNUC__ */
 
-/* byteorder(3) - simimlar to linux <arpa/inet.h> */
-#ifndef __machine_host_to_from_network_defined
-#if _BYTE_ORDER == _LITTLE_ENDIAN
-#define	__htonl(_x)	__bswap32(_x)
-#define	__htons(_x)	__bswap16(_x)
-#define	__ntohl(_x)	__bswap32(_x)
-#define	__ntohs(_x)	__bswap16(_x)
-#define	htonl(_x)	__htonl(_x)
-#define	htons(_x)	__htons(_x)
-#define	ntohl(_x)	__htonl(_x)
-#define	ntohs(_x)	__htons(_x)
-#else
-#define	__htonl(_x)	((__uint32_t)(_x))
-#define	__htons(_x)	((__uint16_t)(_x))
-#define	__ntohl(_x)	((__uint32_t)(_x))
-#define	__ntohs(_x)	((__uint16_t)(_x))
-#define	htonl(_x)	__htonl(_x))
-#define	htons(_x)	__htons(_x))
-#define	ntohl(_x)	__ntohl(_x))
-#define	ntohs(_x)	__ntohs(_x))
-#endif
-#endif /* __machine_host_to_from_network_defined */
-
 /* endian(3) - similar to linux <endian.h> */
-#if __BYTE_ORDER == __LITTLE_ENDIAN
+#if _BYTE_ORDER == _LITTLE_ENDIAN
 #define htobe16(_x) __bswap16(_x)
 #define htole16(_x) ((__uint16_t)(_x))
 #define be16toh(_x) __bswap16(_x)
