@@ -4,14 +4,14 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <ssp/ssp.h>
 #undef puts
 
 static void (*fortify_handler)(int sig);
 
 #define CHK_FAIL_MSG "*** overflow detected ***: terminated"
 
-void
-__attribute__((__noreturn__))
+_Noreturn void
 __chk_fail(void)
 {
 #ifdef TINY_STDIO
