@@ -1,8 +1,8 @@
 /* Copyright (c) 2017 Yaakov Selkowitz <yselkowi@redhat.com> */
-#include <sys/cdefs.h>
 #include <sys/param.h>
 #include <signal.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -16,6 +16,8 @@ uintptr_t __stack_chk_guard = 0;
 
 int     getentropy (void *, size_t) _ATTRIBUTE((__weak__));
 
+void __stack_chk_init (void) __attribute__((__constructor__));
+
 void
 __attribute__((__constructor__))
 __stack_chk_init (void)
@@ -38,12 +40,13 @@ __stack_chk_init (void)
 }
 #endif
 
-void __stack_chk_fail (void) __attribute__((__noreturn__));
+_Noreturn void __stack_chk_fail (void);
 
 #define STACK_CHK_MSG "*** stack smashing detected ***: terminated"
 
-void
-__attribute__((__noreturn__))
+__typeof(__stack_chk_fail) __stack_chk_fail_weak;
+
+_Noreturn void
 __stack_chk_fail_weak (void)
 {
 #ifdef TINY_STDIO
@@ -57,6 +60,9 @@ __stack_chk_fail_weak (void)
 __weak_reference(__stack_chk_fail_weak, __stack_chk_fail);
 
 #ifdef __ELF__
+
+__typeof(__stack_chk_fail) __stack_chk_fail_local;
+
 void
 __attribute__((visibility ("hidden")))
 __stack_chk_fail_local (void)
