@@ -168,7 +168,7 @@ _printf_float (struct _reent *data,
 {
 #define _fpvalue (pdata->_double_)
 
-  char *decimal_point = localeconv ()->decimal_point;
+  char *decimal_point = DECIMAL_POINT;
   size_t decp_len = strlen (decimal_point);
   /* Temporary negative sign for floats.  */
   char softsign;
