@@ -16,8 +16,6 @@
  */
 
 #define _DEFAULT_SOURCE
-#include <_ansi.h>
-#include <newlib.h>
 #include <ctype.h>
 #include <wctype.h>
 #include <stdio.h>
