@@ -26,20 +26,12 @@
 
 #define _GNU_SOURCE
 #define _DEFAULT_SOURCE
-#include <_ansi.h>
 #include <stdio.h>
 #include <wchar.h>
 #include "local.h"
 
 #undef putwchar_unlocked
 
-wint_t
-_putwchar_unlocked_r (struct _reent *ptr,
-	wchar_t wc)
-{
-  return _fputwc_unlocked_r (ptr, wc, stdout);
-}
-
 /*
  * Synonym for fputwc_unlocked(wc, stdout).
  */
