@@ -604,7 +604,7 @@ siprintf (char *, const char *, ...)
 
 #ifdef __LONG_DOUBLE_IEEE128__
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(sprintf, __sprintfieee128);
