@@ -16,8 +16,7 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef _REENT_ONLY
-
+#define _DEFAULT_SOURCE
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
@@ -147,5 +146,3 @@ unsetenv (const char *name)
   ENV_UNLOCK;
   return 0;
 }
-
-#endif /* !_REENT_ONLY */
