@@ -42,7 +42,7 @@ static char sccsid[] = "from @(#)strtol.c	8.1 (Berkeley) 6/4/93";
 #include <stdlib.h>
 #include <inttypes.h>
 #include <stdint.h>
-#include "../locale/setlocale.h"
+#include "local.h"
 
 /*
  * Convert a string to an intmax_t integer.
