@@ -117,7 +117,7 @@ PORTABILITY
 #include <ctype.h>
 #include <errno.h>
 #include <stdlib.h>
-#include "../locale/setlocale.h"
+#include "local.h"
 
 /*
  * Convert a string to an unsigned long long integer.
