@@ -30,7 +30,7 @@ QUICKREF
 	memrchr
 */
 
-#include <_ansi.h>
+#define _GNU_SOURCE
 #include <string.h>
 #include <limits.h>
 #include <stdint.h>
