@@ -49,14 +49,13 @@ wcswidth (const wchar_t *pwcs,
     uint32_t wi = (uint32_t) *pwcs;
 
 #ifdef _MB_CAPABLE
-  wi = _jp2uc (wi);
   /* First half of a surrogate pair? */
   if (sizeof (wchar_t) == 2 && wi >= (uint32_t) 0xd800 && wi <= (uint32_t) 0xdbff)
     {
       uint32_t wi2;
 
       /* Extract second half and check for validity. */
-      if (--n == 0 || (wi2 = _jp2uc (*++pwcs)) < (uint32_t) 0xdc00 || wi2 > (uint32_t) 0xdfff)
+      if (--n == 0 || (wi2 = *++pwcs) < (uint32_t) 0xdc00 || wi2 > (uint32_t) 0xdfff)
 	return -1;
       /* Compute actual unicode value to use in call to __wcwidth. */
       wi = (((wi & 0x3ff) << 10) | (wi2 & 0x3ff)) + 0x10000;
