@@ -57,7 +57,7 @@ fdopen(int fd, const char *mode)
         buf = (char *) (bf + 1);
 
         *bf = (struct __file_bufio)
-                FDEV_SETUP_POSIX(fd, buf, BUFSIZ, stdio_flags, 0);
+                FDEV_SETUP_POSIX(fd, buf, BUFSIZ, stdio_flags, __BFALL);
 
         __bufio_lock_init(&(bf->xfile.cfile.file));
 
