@@ -38,3 +38,10 @@ putchar(int c)
 {
 	return putc(c, stdout);
 }
+
+#undef putchar_unlocked
+#ifdef _HAVE_ALIAS_ATTRIBUTE
+__strong_reference(putchar, putchar_unlocked);
+#else
+int putchar_unlocked(int c) { return putchar(c); }
+#endif
