@@ -49,7 +49,7 @@ sprintf(char *s, const char *fmt, ...)
 
 #ifdef __LONG_DOUBLE_IEEE128__
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(sprintf, __sprintfieee128);
