@@ -57,7 +57,7 @@ vsnprintf(char *s, size_t n, const char *fmt, va_list ap)
 
 #ifdef __LONG_DOUBLE_IEEE128__
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(vsnprintf, __vsnprintfieee128);
