@@ -398,7 +398,7 @@ pow (double x, double y)
 }
 
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(pow, _pow);
