@@ -102,7 +102,7 @@ lround64(__float64 x)
         {
 	  /* 32bit long: exponent_less_1023 in [20,30] */
 	  /* 64bit long: exponent_less_1023 in [20,51] */
-          unsigned int tmp = lsw
+          __uint32_t tmp = lsw
 		    /* 32bit long: shift amt in [0,10] */
 		    /* 64bit long: shift amt in [0,31] */
                     + (0x80000000 >> (exponent_less_1023 - 20));
@@ -120,7 +120,7 @@ lround64(__float64 x)
   {
     /* Result is too large to be represented by a long int. */
     if (sign == 1 ||
-        !((sizeof(long) == 4 && x > LONG_MIN - 0.5) ||
+        !((sizeof(long) == 4 && x > LONG_MIN - _F_64(0.5)) ||
           (sizeof(long) > 4 && x >= LONG_MIN)))
     {
       __math_set_invalid();
