@@ -21,12 +21,7 @@
 #include "fdlibm.h"
 
 float
-#ifdef __STDC__
 logbf(float x)
-#else
-logbf(x)
-float x;
-#endif
 {
 	__int32_t hx,ix;
 
@@ -41,20 +36,8 @@ float x;
 	    return (float) ix;
 	}
 	else if (FLT_UWORD_IS_INFINITE(hx)) return HUGE_VALF;	/* x==+|-inf */
-	else if (FLT_UWORD_IS_NAN(hx)) return x;
+	else if (FLT_UWORD_IS_NAN(hx)) return x + x;
 	else return (float) ((hx>>23)-127);
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-#ifdef __STDC__
-	double logb(double x)
-#else
-	double logb(x)
-	double x;
-#endif
-{
-	return (double) logbf((float) x);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_f_f(logb)
