@@ -41,8 +41,7 @@ cacosl(long double complex z)
 	long double complex w;
 
 	w = casinl(z);
-	w = (M_PI_2L - creall(w)) - cimagl(w) * (long double complex) I;
-	return w;
+	return (long double complex) (M_PI_2L - creall(w)) - cimagl(w) * (long double complex) I;
 }
 
 #endif
