@@ -37,14 +37,12 @@
 long double complex
 clogl(long double complex z)
 {
-	long double complex w;
 	long double p, rr;
 
 	rr = cabsl(z);
 	p = logl(rr);
 	rr = atan2l(cimagl(z), creall(z));
-	w = p + rr * (long double complex) I;
-	return w;
+	return (long double complex) p + rr * (long double complex) I;
 }
 
 #endif
