@@ -104,7 +104,7 @@ atan2l(long double y, long double x)
 
 #if __LDBL_MANT_DIG__ == 113
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(atan2l, __atan2ieee128);
