@@ -18,7 +18,7 @@ sincosl( long double x, long double * s, long double * c )
 
 #if __LDBL_MANT_DIG__ == 113
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(sincosl, __sincosieee128);
