@@ -35,7 +35,7 @@
 
 #include <math.h>
 
-#if defined(__riscv_flen) && __riscv_flen >= 64
+#if defined(__RISCV_HARD_FLOAT) && __RISCV_HARD_FLOAT >= 64
 
 double
 fmax (double x, double y)
