@@ -15,8 +15,14 @@ is preserved.
 
 #include "fdlibm.h"
 
-double
-drem(double x, double y)
+#ifdef _NEED_FLOAT64
+
+__float64
+drem64(__float64 x, __float64 y)
 {
-    return remainder(x, y);
+    return remainder64(x, y);
 }
+
+_MATH_ALIAS_d_dd(drem)
+
+#endif
