@@ -354,7 +354,7 @@ pow64(__float64 x, __float64 y)
 }
 
 #if defined(_HAVE_ALIAS_ATTRIBUTE)
-#ifndef __clang__
+#if defined(__GNUCLIKE_PRAGMA_DIAGNOSTIC) && !defined(__clang__)
 #pragma GCC diagnostic ignored "-Wmissing-attributes"
 #endif
 __strong_reference(pow64, _pow64);
