@@ -104,12 +104,4 @@ atanf(float x)
     }
 }
 
-#ifdef _DOUBLE_IS_32BITS
-
-double
-atan(double x)
-{
-    return (double)atanf((float)x);
-}
-
-#endif /* defined(_DOUBLE_IS_32BITS) */
+_MATH_ALIAS_f_f(atan)
