@@ -24,7 +24,7 @@ lgammaf(float x)
 }
 
 #  ifdef _HAVE_ALIAS_ATTRIBUTE
-#ifdef __GNUC__
+#ifdef __GNUCLIKE_PRAGMA_DIAGNOSTIC
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
 #pragma GCC diagnostic ignored "-Wattribute-alias="
