@@ -302,4 +302,4 @@
 {58, 0,123,__LINE__, 0xbfd5a705, 0x9eaeac43, 0x403d7fff, 0xfffffffc},	/* -0.338319=f(29.5)*/
 {0}
 };
-void test_cos(m)   {run_vector_1(m,cos_vec,(char *)(cos),"cos","dd");   }	
+void test_cos(int m)   {run_vector_1(m,cos_vec,(char *)(cos),"cos","dd");   }	
