@@ -20,9 +20,9 @@
 
 #include <math.h>
 #include <float.h>
-//#include <ieeefp.h>
 #include <stdio.h>
 #include <stdint.h>
+#include <stdlib.h>
 
 #ifdef INCLUDE_GENERATE
 #define TEST_CONST
@@ -215,6 +215,7 @@ int fmag_of_error (float, float);
   char buffer[100];\
    sprintf(buffer,"%s_vec.c",x);\
     f = fopen(buffer,"w");\
+    if (!f) { perror(buffer); exit(1); } \
      fprintf(f,"#include \"test.h\"\n");\
       fprintf(f," one_line_type %s_vec[] = {\n", x);\
 }
@@ -553,7 +554,7 @@ void
 test_y1f(int vector);
 
 void
-test_y1f(int vector);
+test_yn(int vector);
 
 void
 test_ynf(int vector);
