@@ -79,9 +79,11 @@ check_contents(char *template,int repeats)
 }
 
 /* Allow testing mktemp which is deprecated (for good reason) */
+#if ((__GNUC__ == 4 && __GNUC_MINOR__ >= 2) || __GNUC__ > 4)
 #pragma GCC diagnostic ignored "-Wpragmas"
 #pragma GCC diagnostic ignored "-Wunknown-warning-option"
 #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
 
 int
 main(void)
